@@ -3,7 +3,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2018 Alban 'spl0k' Féron
+# Copyright (C) 2018-2020 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -21,7 +21,7 @@ methods = (
 
 
 def unsupported():
-    return GenericError("Not supported by Supysonic"), 501
+    return GenericError("Not supported by Supysonic")
 
 
 for m in methods:
