@@ -3,7 +3,7 @@
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2013-2019 Alban 'spl0k' Féron
+# Copyright (C) 2013-2020 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
@@ -23,7 +23,7 @@ from pony.orm import db_session
 from urllib.parse import urlparse, parse_qsl
 from uuid import UUID, uuid4
 
-SCHEMA_VERSION = "20190921"
+SCHEMA_VERSION = "20200607"
 
 
 def now():
@@ -553,12 +553,33 @@ class Playlist(db.Entity):
         self.tracks = ",".join(t for t in tracks if t)
 
 
+class RadioStation(db.Entity):
+    _table_ = "radio_station"
+
+    id = PrimaryKey(UUID, default=uuid4)
+    stream_url = Required(str)
+    name = Required(str)
+    homepage_url = Optional(str, nullable=True)
+    created = Required(datetime, precision=0, default=now)
+
+    def as_subsonic_station(self):
+        info = dict(
+            id=str(self.id),
+            streamUrl=self.stream_url,
+            name=self.name,
+            homePageUrl=self.homepage_url,
+        )
+        return info
+
+
 def parse_uri(database_uri):
     if not isinstance(database_uri, str):
         raise TypeError("Expecting a string")
 
     uri = urlparse(database_uri)
     args = dict(parse_qsl(uri.query))
+    if uri.port is not None:
+        args["port"] = uri.port
 
     if uri.scheme == "sqlite":
         path = uri.path
@@ -645,9 +666,12 @@ def init_database(database_uri):
     else:
         metadb.disconnect()
         db.bind(**settings)
+        # Force requests to Meta to use the same connection as other tables
+        metadb.provider = db.provider
 
     db.generate_mapping(check_tables=False)
 
+
 def release_database():
     metadb.disconnect()
     db.disconnect()
